@@ -187,6 +187,36 @@ class StormlibModelTest(s_test.SynTest):
                 with self.raises(s_exc.IsDeprLocked):
                     await core.nodes('[ou:hasalias=(*, hehe)]')
 
+                with self.getAsyncLoggerStream('synapse.lib.snap',
+                                               'Prop ou:org:sic is locked due to deprecation') as stream:
+                    data = (
+                        (('ou:org', ('t0',)), {'props': {'sic': '5678'}}),
+                    )
+                    await core.addFeedData('syn.nodes', data)
+                    self.true(await stream.wait(1))
+                    nodes = await core.nodes('ou:org=(t0,)')
+                    self.none(nodes[0].get('sic'))
+
+                # Coverage test for node.set() / snap.getNodeAdds
+                async with await core.snap() as snap:
+                    snap.strict = False
+                    _msgs = []
+                    def append(evnt):
+                        _msgs.append(evnt)
+                    snap.link(append)
+                    nodes = await snap.nodes('ou:org=(t0,) [ :sic=5678 ]')
+                    snap.unlink(append)
+                    self.stormIsInWarn('Prop ou:org:sic is locked due to deprecation', _msgs)
+                    self.none(nodes[0].get('sic'))
+
+                    snap.strict = True
+                    form, valu = nodes[0].ndef
+                    form = core.model.form(form)
+                    props = {'sic': '5678'}
+                    with self.raises(s_exc.IsDeprLocked):
+                        _ = await snap.getNodeAdds(form, valu, props, addnode=False)
+                # End coverage test
+
                 mesgs = await core.stormlist('model.deprecated.locks')
                 self.stormIsInPrint('ou:org:sic: True', mesgs)
                 self.stormIsInPrint('ou:hasalias: True', mesgs)
