@@ -1016,6 +1016,102 @@ class TypesTest(s_t_utils.SynTest):
             await self.agenlen(3, core.eval('test:str:tick*range=(2018/12/02, "+86401 seconds")'))
             await self.agenlen(3, core.eval('test:str:tick*range=(2018/12/02, "+25 hours")'))
 
+            self.len(0, await core.nodes('test:guid | delnode --force'))
+            await core.nodes('[ test:guid=* :tick=20211031020202 ]')
+
+            # test * suffix syntax
+            self.len(1, await core.nodes('test:guid:tick=2021*'))
+            self.len(1, await core.nodes('test:guid:tick=202110*'))
+            self.len(1, await core.nodes('test:guid:tick=20211031*'))
+            self.len(1, await core.nodes('test:guid:tick=2021103102*'))
+            self.len(1, await core.nodes('test:guid:tick=202110310202*'))
+            self.len(1, await core.nodes('test:guid:tick=20211031020202*'))
+
+            self.len(0, await core.nodes('test:guid:tick=2022*'))
+            self.len(0, await core.nodes('test:guid:tick=202210*'))
+            self.len(0, await core.nodes('test:guid:tick=20221031*'))
+            self.len(0, await core.nodes('test:guid:tick=2022103102*'))
+            self.len(0, await core.nodes('test:guid:tick=202210310202*'))
+            self.len(0, await core.nodes('test:guid:tick=20221031020202*'))
+
+            self.len(1, await core.nodes('test:guid +:tick=2021*'))
+            self.len(1, await core.nodes('test:guid +:tick=202110*'))
+            self.len(1, await core.nodes('test:guid +:tick=20211031*'))
+            self.len(1, await core.nodes('test:guid +:tick=2021103102*'))
+            self.len(1, await core.nodes('test:guid +:tick=202110310202*'))
+            self.len(1, await core.nodes('test:guid +:tick=20211031020202*'))
+
+            self.len(0, await core.nodes('test:guid -:tick=2021*'))
+            self.len(0, await core.nodes('test:guid -:tick=202110*'))
+            self.len(0, await core.nodes('test:guid -:tick=20211031*'))
+            self.len(0, await core.nodes('test:guid -:tick=2021103102*'))
+            self.len(0, await core.nodes('test:guid -:tick=202110310202*'))
+            self.len(0, await core.nodes('test:guid -:tick=20211031020202*'))
+
+            # test <= time * suffix syntax
+            self.len(1, await core.nodes('test:guid:tick<=2021*'))
+            self.len(1, await core.nodes('test:guid:tick<=202110*'))
+            self.len(1, await core.nodes('test:guid:tick<=20211031*'))
+            self.len(1, await core.nodes('test:guid:tick<=2021103102*'))
+            self.len(1, await core.nodes('test:guid:tick<=202110310202*'))
+            self.len(1, await core.nodes('test:guid:tick<=20211031020202*'))
+
+            self.len(0, await core.nodes('test:guid:tick<=2020*'))
+            self.len(0, await core.nodes('test:guid:tick<=202010*'))
+            self.len(0, await core.nodes('test:guid:tick<=20201031*'))
+            self.len(0, await core.nodes('test:guid:tick<=2020103102*'))
+            self.len(0, await core.nodes('test:guid:tick<=202010310202*'))
+            self.len(0, await core.nodes('test:guid:tick<=20201031020202*'))
+
+            self.len(1, await core.nodes('test:guid +:tick<=2021*'))
+            self.len(1, await core.nodes('test:guid +:tick<=202110*'))
+            self.len(1, await core.nodes('test:guid +:tick<=20211031*'))
+            self.len(1, await core.nodes('test:guid +:tick<=2021103102*'))
+            self.len(1, await core.nodes('test:guid +:tick<=202110310202*'))
+            self.len(1, await core.nodes('test:guid +:tick<=20211031020202*'))
+
+            self.len(0, await core.nodes('test:guid -:tick<=2021*'))
+            self.len(0, await core.nodes('test:guid -:tick<=202110*'))
+            self.len(0, await core.nodes('test:guid -:tick<=20211031*'))
+            self.len(0, await core.nodes('test:guid -:tick<=2021103102*'))
+            self.len(0, await core.nodes('test:guid -:tick<=202110310202*'))
+            self.len(0, await core.nodes('test:guid -:tick<=20211031020202*'))
+
+            # test <= time * suffix syntax
+            self.len(1, await core.nodes('test:guid:tick<2021*'))
+            self.len(1, await core.nodes('test:guid:tick<202110*'))
+            self.len(1, await core.nodes('test:guid:tick<20211031*'))
+            self.len(1, await core.nodes('test:guid:tick<2021103102*'))
+            self.len(1, await core.nodes('test:guid:tick<202110310202*'))
+            self.len(1, await core.nodes('test:guid:tick<20211031020202*'))
+
+            self.len(0, await core.nodes('test:guid:tick<2020*'))
+            self.len(0, await core.nodes('test:guid:tick<202010*'))
+            self.len(0, await core.nodes('test:guid:tick<20201031*'))
+            self.len(0, await core.nodes('test:guid:tick<2020103102*'))
+            self.len(0, await core.nodes('test:guid:tick<202010310202*'))
+            self.len(0, await core.nodes('test:guid:tick<20201031020202*'))
+
+            self.len(1, await core.nodes('test:guid +:tick<2021*'))
+            self.len(1, await core.nodes('test:guid +:tick<202110*'))
+            self.len(1, await core.nodes('test:guid +:tick<20211031*'))
+            self.len(1, await core.nodes('test:guid +:tick<2021103102*'))
+            self.len(1, await core.nodes('test:guid +:tick<202110310202*'))
+            self.len(1, await core.nodes('test:guid +:tick<20211031020202*'))
+
+            self.len(0, await core.nodes('test:guid -:tick<2021*'))
+            self.len(0, await core.nodes('test:guid -:tick<202110*'))
+            self.len(0, await core.nodes('test:guid -:tick<20211031*'))
+            self.len(0, await core.nodes('test:guid -:tick<2021103102*'))
+            self.len(0, await core.nodes('test:guid -:tick<202110310202*'))
+            self.len(0, await core.nodes('test:guid -:tick<20211031020202*'))
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('test:guid:tick=202*')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('test:guid:tick=202110310202021*')
+
         async with self.getTestCore() as core:
 
             async with await core.snap() as snap:
