@@ -469,7 +469,9 @@ class InfotechModelTest(s_t_utils.SynTest):
                     'released': '2018-04-03 08:44:22',
                     'url': url1,
                     'software': prod0,
-                    'arch': 'amd64'
+                    'arch': 'amd64',
+                    'name': 'balloonmaker',
+                    'desc': 'makes balloons',
                 }
                 ver0 = s_common.guid()
                 node = await snap.addNode('it:prod:softver', ver0, vprops)
@@ -488,6 +490,8 @@ class InfotechModelTest(s_t_utils.SynTest):
                 self.eq(node.get('semver:pre'), 'beta')
                 self.eq(node.get('semver:build'), 'exp.sha.5114f85')
                 self.eq(node.get('url'), url1)
+                self.eq(node.get('name'), 'balloonmaker')
+                self.eq(node.get('desc'), 'makes balloons')
                 # callback node creation checks
                 nodes = await snap.nodes('it:dev:str=V1.0.1-beta+exp.sha.5114f85')
                 self.len(1, nodes)
@@ -1152,3 +1156,36 @@ class InfotechModelTest(s_t_utils.SynTest):
 
             nodes = await core.nodes(f'file:bytes={baseFile} -> it:reveng:filefunc -> it:reveng:function -> it:reveng:impfunc')
             self.len(len(impcalls), nodes)
+
+    async def test_infotech_cpes(self):
+
+        async with self.getTestCore() as core:
+
+            cpe23 = core.model.type('it:sec:cpe')
+            cpe22 = core.model.type('it:sec:cpe:v2_2')
+
+            with self.raises(s_exc.BadTypeValu):
+                cpe22.norm('cpe:/a:vertex:synapse:0:1:2:3:4:5:6:7:8:9')
+
+            with self.raises(s_exc.BadTypeValu):
+                cpe23.norm('cpe:/a:vertex:synapse:0:1:2:3:4:5:6:7:8:9')
+
+            with self.raises(s_exc.BadTypeValu):
+                cpe23.norm('cpe:2.3:a:vertex:synapse')
+
+            # test cast 2.2 -> 2.3 upsample
+            norm, info = cpe23.norm('cpe:/a:vertex:synapse')
+            self.eq(norm, 'cpe:2.3:a:vertex:synapse:*:*:*:*:*:*:*:*')
+
+            # test cast 2.3 -> 2.2 downsample
+            norm, info = cpe22.norm('cpe:2.3:a:vertex:synapse:*:*:*:*:*:*:*:*')
+            self.eq(norm, 'cpe:/a:vertex:synapse')
+
+            nodes = await core.nodes('[ it:sec:cpe=cpe:2.3:a:vertex:synapse:*:*:*:*:*:*:*:* ]')
+            self.eq('cpe:/a:vertex:synapse', nodes[0].props['v2_2'])
+
+            # test lift by either via upsample and downsample
+            self.len(1, await core.nodes('it:sec:cpe=cpe:/a:vertex:synapse +:v2_2=cpe:/a:vertex:synapse'))
+            self.len(1, await core.nodes('it:sec:cpe=cpe:2.3:a:vertex:synapse:*:*:*:*:*:*:*:*'))
+            self.len(1, await core.nodes('it:sec:cpe:v2_2=cpe:/a:vertex:synapse'))
+            self.len(1, await core.nodes('it:sec:cpe:v2_2=cpe:2.3:a:vertex:synapse:*:*:*:*:*:*:*:*'))
